@@ -27,7 +27,7 @@ class Sequence(Generic[T], Iterable[T]):
     def __init__(self, v: Iterable[T]) -> None:
         super().__init__()
         self._iter = v
-        self._cache = None
+        self._cache = v if type(self) == Sequence and type(v) == list else None
 
     def filter(self, predicate: Callable[[T], bool]) -> Sequence[T]:
         """
@@ -35,7 +35,7 @@ class Sequence(Generic[T], Iterable[T]):
 
          Example 1:
         >>> lst = [ 'a1', 'b1', 'b2', 'a2']
-        >>> it(lst).filter(lambda x: x.startswith('a'))
+        >>> it(lst).filter(lambda x: x.startswith('a')).to_list()
         ['a1', 'a2']
         """
         return FilteringSequence(self, predicate)
@@ -46,7 +46,7 @@ class Sequence(Generic[T], Iterable[T]):
 
          Example 1:
         >>> lst = [ 'a1', 'b1', 'b2', 'a2']
-        >>> it(lst).filter_indexed(lambda x, i: i == 2)
+        >>> it(lst).filter_indexed(lambda x, i: i == 2).to_list()
         ['b2']
         """
         return IndexingSequence(self).filter(lambda x: predicate(x.value, x.index)).map(lambda x: x.value)
@@ -57,7 +57,7 @@ class Sequence(Generic[T], Iterable[T]):
 
         Example 1:
         >>> lst = [ 'a1', 1, 'b2', 3]
-        >>> it(lst).filter_is_instance(int)
+        >>> it(lst).filter_is_instance(int).to_list()
         [1, 3]
 
         """
@@ -69,7 +69,7 @@ class Sequence(Generic[T], Iterable[T]):
 
          Example 1:
         >>> lst = [ 'a1', 'b1', 'b2', 'a2']
-        >>> it(lst).filter_not(lambda x: x.startswith('a'))
+        >>> it(lst).filter_not(lambda x: x.startswith('a')).to_list()
         ['b1', 'b2']
         """
         return self.filter(lambda x: not predicate(x))
@@ -80,7 +80,7 @@ class Sequence(Generic[T], Iterable[T]):
 
          Example 1:
         >>> lst = [ 'a', None, 'b']
-        >>> it(lst).filter_not_none()
+        >>> it(lst).filter_not_none().to_list()
         ['a', 'b']
         """
         return self.filter(lambda x: x is not None)
@@ -92,7 +92,7 @@ class Sequence(Generic[T], Iterable[T]):
 
          Example 1:
         >>> lst = [{ 'name': 'A', 'age': 12}, { 'name': 'B', 'age': 13}]
-        >>> it(lst).map(lambda x: x['age'])
+        >>> it(lst).map(lambda x: x['age']).to_list()
         [12, 13]
         """
         return MappingSequence(self, transform)
@@ -105,7 +105,7 @@ class Sequence(Generic[T], Iterable[T]):
 
          Example 1:
         >>> lst = [{ 'name': 'A', 'age': 12}, { 'name': 'B', 'age': 13}]
-        >>> it(lst).map_indexed(lambda x, i: x['age'] + i)
+        >>> it(lst).map_indexed(lambda x, i: x['age'] + i).to_list()
         [12, 14]
         """
         return IndexingSequence(self).map(lambda x: transform(x.value, x.index))
@@ -118,7 +118,7 @@ class Sequence(Generic[T], Iterable[T]):
 
          Example 1:
         >>> lst = [{ 'name': 'A', 'age': 12}, { 'name': 'B', 'age': None}]
-        >>> it(lst).map_not_none(lambda x: x['age'])
+        >>> it(lst).map_not_none(lambda x: x['age']).to_list()
         [12]
         """
         return self.map(transform).filter_not_none()
@@ -131,12 +131,12 @@ class Sequence(Generic[T], Iterable[T]):
 
          Example 1:
         >>> lst = [{ 'name': 'A', 'age': 12}, { 'name': 'B', 'age': 13}]
-        >>> it(lst).parallel_map(lambda x: x['age'])
+        >>> it(lst).parallel_map(lambda x: x['age']).to_list()
         [12, 13]
 
          Example 2:
         >>> lst = [{ 'name': 'A', 'age': 12}, { 'name': 'B', 'age': 13}]
-        >>> it(lst).parallel_map(lambda x: x['age'], max_workers=2)
+        >>> it(lst).parallel_map(lambda x: x['age'], max_workers=2).to_list()
         [12, 13]
         """
         return ParallelMappingSequence(self, transform, max_workers, chunksize, executor)
@@ -545,18 +545,18 @@ class Sequence(Generic[T], Iterable[T]):
 
          Example 1:
         >>> lst = ['a', 'b', 'c']
-        >>> it(lst).drop(0)
+        >>> it(lst).drop(0).to_list()
         ['a', 'b', 'c']
 
          Example 2:
         >>> lst = ['a', 'b', 'c']
-        >>> it(lst).drop(1)
+        >>> it(lst).drop(1).to_list()
         ['b', 'c']
 
 
          Example 2:
         >>> lst = ['a', 'b', 'c']
-        >>> it(lst).drop(4)
+        >>> it(lst).drop(4).to_list()
         []
         """
         if n < 0:
@@ -573,7 +573,7 @@ class Sequence(Generic[T], Iterable[T]):
 
          Example 1:
         >>> lst = [1, 2, 3, 4, 1]
-        >>> it(lst).drop_while(lambda x: x < 3 )
+        >>> it(lst).drop_while(lambda x: x < 3 ).to_list()
         [3, 4, 1]
         """
         return DropWhileSequence(self, predicate)
@@ -584,18 +584,18 @@ class Sequence(Generic[T], Iterable[T]):
 
          Example 1:
         >>> lst = ['a', 'b', 'c']
-        >>> it(lst).skip(0)
+        >>> it(lst).skip(0).to_list()
         ['a', 'b', 'c']
 
          Example 2:
         >>> lst = ['a', 'b', 'c']
-        >>> it(lst).skip(1)
+        >>> it(lst).skip(1).to_list()
         ['b', 'c']
 
 
          Example 2:
         >>> lst = ['a', 'b', 'c']
-        >>> it(lst).skip(4)
+        >>> it(lst).skip(4).to_list()
         []
         """
         return self.drop(n)
@@ -606,7 +606,7 @@ class Sequence(Generic[T], Iterable[T]):
 
          Example 1:
         >>> lst = [1, 2, 3, 4, 1]
-        >>> it(lst).skip_while(lambda x: x < 3 )
+        >>> it(lst).skip_while(lambda x: x < 3 ).to_list()
         [3, 4, 1]
         """
         return self.drop_while(predicate)
@@ -618,13 +618,13 @@ class Sequence(Generic[T], Iterable[T]):
 
          Example 1:
         >>> a = ['a', 'b', 'c']
-        >>> it(a).take(0)
+        >>> it(a).take(0).to_list()
         []
 
 
          Example 2:
         >>> a = ['a', 'b', 'c']
-        >>> it(a).take(2)
+        >>> it(a).take(2).to_list()
         ['a', 'b']
 
         """
@@ -641,7 +641,7 @@ class Sequence(Generic[T], Iterable[T]):
 
          Example 1:
         >>> lst = ['a', 'b', 'c', 'd']
-        >>> it(lst).take_while(lambda x: x in ['a', 'b'])
+        >>> it(lst).take_while(lambda x: x in ['a', 'b']).to_list()
         ['a', 'b']
 
         """
@@ -653,13 +653,13 @@ class Sequence(Generic[T], Iterable[T]):
 
          Example 1:
         >>> a = ['a', 'b', 'c']
-        >>> it(a).take_last(0)
+        >>> it(a).take_last(0).to_list()
         []
 
 
          Example 2:
         >>> a = ['a', 'b', 'c']
-        >>> it(a).take_last(2)
+        >>> it(a).take_last(2).to_list()
         ['b', 'c']
 
         """
@@ -677,12 +677,12 @@ class Sequence(Generic[T], Iterable[T]):
 
          Example 1:
         >>> lst = ['b', 'a', 'e', 'c']
-        >>> it(lst).sorted()
+        >>> it(lst).sorted().to_list()
         ['a', 'b', 'c', 'e']
 
          Example 2:
         >>> lst = [2, 1, 4, 3]
-        >>> it(lst).sorted()
+        >>> it(lst).sorted().to_list()
         [1, 2, 3, 4]
         """
         lst = list(self)
@@ -697,9 +697,9 @@ class Sequence(Generic[T], Iterable[T]):
 
          Example 1:
         >>> lst = [ {'name': 'A', 'age': 12 }, {'name': 'C', 'age': 10 }, {'name': 'B', 'age': 11 } ]
-        >>> it(lst).sorted_by(lambda x: x['name'])
+        >>> it(lst).sorted_by(lambda x: x['name']).to_list()
         [{'name': 'A', 'age': 12}, {'name': 'B', 'age': 11}, {'name': 'C', 'age': 10}]
-        >>> it(lst).sorted_by(lambda x: x['age'])
+        >>> it(lst).sorted_by(lambda x: x['age']).to_list()
         [{'name': 'C', 'age': 10}, {'name': 'B', 'age': 11}, {'name': 'A', 'age': 12}]
 
         """
@@ -713,7 +713,7 @@ class Sequence(Generic[T], Iterable[T]):
 
          Example 1:
         >>> lst = ['b', 'c', 'a']
-        >>> it(lst).sorted_descending()
+        >>> it(lst).sorted_descending().to_list()
         ['c', 'b', 'a']
         """
         return self.sorted().reversed()
@@ -725,9 +725,9 @@ class Sequence(Generic[T], Iterable[T]):
 
          Example 1:
         >>> lst = [ {'name': 'A', 'age': 12 }, {'name': 'C', 'age': 10 }, {'name': 'B', 'age': 11 } ]
-        >>> it(lst).sorted_by_descending(lambda x: x['name'])
+        >>> it(lst).sorted_by_descending(lambda x: x['name']).to_list()
         [{'name': 'C', 'age': 10}, {'name': 'B', 'age': 11}, {'name': 'A', 'age': 12}]
-        >>> it(lst).sorted_by_descending(lambda x: x['age'])
+        >>> it(lst).sorted_by_descending(lambda x: x['age']).to_list()
         [{'name': 'A', 'age': 12}, {'name': 'B', 'age': 11}, {'name': 'C', 'age': 10}]
         """
         return self.sorted_by(key_selector).reversed()
@@ -739,7 +739,7 @@ class Sequence(Generic[T], Iterable[T]):
 
         Example 1:
         >>> lst = ['aa', 'bbb', 'c']
-        >>> it(lst).sorted_with(lambda a, b: len(a)-len(b))
+        >>> it(lst).sorted_with(lambda a, b: len(a)-len(b)).to_list()
         ['c', 'aa', 'bbb']
         """
         from functools import cmp_to_key
@@ -1007,12 +1007,12 @@ class Sequence(Generic[T], Iterable[T]):
 
          Example 1:
         >>> lst = [1, 2, 3, 1, 2, 3]
-        >>> it(lst).distinct()
+        >>> it(lst).distinct().to_list()
         [1, 2, 3]
 
          Example 2:
         >>> lst = [(1, 'A'), (1, 'A'), (1, 'A'), (2, 'A'), (3, 'C'), (3, 'D')]
-        >>> it(lst).distinct().sorted()
+        >>> it(lst).distinct().sorted().to_list()
         [(1, 'A'), (2, 'A'), (3, 'C'), (3, 'D')]
 
         """
@@ -1024,7 +1024,7 @@ class Sequence(Generic[T], Iterable[T]):
 
          Example 1:
         >>> lst = [1, 2, 3, 1, 2, 3]
-        >>> it(lst).distinct_by(lambda x: x%2)
+        >>> it(lst).distinct_by(lambda x: x%2).to_list()
         [1, 2]
 
         """
@@ -1260,7 +1260,7 @@ class Sequence(Generic[T], Iterable[T]):
 
          Example 1:
         >>> lst = ['b', 'c', 'a']
-        >>> it(lst).reversed()
+        >>> it(lst).reversed().to_list()
         ['a', 'c', 'b']
         """
         lst = list(self)
@@ -1274,7 +1274,7 @@ class Sequence(Generic[T], Iterable[T]):
 
          Example 1:
         >>> lst = [['a', 'b'], ['c'], ['d', 'e']]
-        >>> it(lst).flat_map(lambda x: x)
+        >>> it(lst).flat_map(lambda x: x).to_list()
         ['a', 'b', 'c', 'd', 'e']
         """
         return FlatteningSequence(self, transform)
@@ -1286,7 +1286,7 @@ class Sequence(Generic[T], Iterable[T]):
 
          Example 1:
         >>> lst = [['a', 'b'], ['c'], ['d', 'e']]
-        >>> it(lst).flatten()
+        >>> it(lst).flatten().to_list()
         ['a', 'b', 'c', 'd', 'e']
         """
         ...
@@ -1305,7 +1305,7 @@ class Sequence(Generic[T], Iterable[T]):
 
          Example 1:
         >>> lst = [['a', 'b'], ['c'], ['d', 'e']]
-        >>> it(lst).flatten()
+        >>> it(lst).flatten().to_list()
         ['a', 'b', 'c', 'd', 'e']
         """
         return FlatteningSequence(self)
@@ -1318,7 +1318,7 @@ class Sequence(Generic[T], Iterable[T]):
 
          Example 1:
         >>> lst = [1, 2, 3, 4, 5]
-        >>> it(lst).group_by(lambda x: x%2)
+        >>> it(lst).group_by(lambda x: x%2).map(lambda x: (x[0], x[1].to_list())).to_list()
         [(1, [1, 3, 5]), (0, [2, 4])]
         """
         return GroupingSequence(self, key_selector)
@@ -1447,13 +1447,13 @@ class Sequence(Generic[T], Iterable[T]):
          Example 1:
         >>> lst1 = ['a', 'b', 'c']
         >>> lst2 = [1, 2, 3]
-        >>> it(lst1).zip(lst2)
+        >>> it(lst1).zip(lst2).to_list()
         [('a', 1), ('b', 2), ('c', 3)]
 
          Example 2:
         >>> lst1 = ['a', 'b', 'c']
         >>> lst2 = [1, 2, 3]
-        >>> it(lst1).zip(lst2, lambda x, y: x + '__' +str( y))
+        >>> it(lst1).zip(lst2, lambda x, y: x + '__' +str( y)).to_list()
         ['a__1', 'b__2', 'c__3']
         """
         ...
@@ -1471,12 +1471,12 @@ class Sequence(Generic[T], Iterable[T]):
         
          Example 1:
         >>> lst = ['a', 'b', 'c']
-        >>> it(lst).zip_with_next(lambda x, y: x + '__' + y)
+        >>> it(lst).zip_with_next(lambda x, y: x + '__' + y).to_list()
         ['a__b', 'b__c']
 
          Example 2:
         >>> lst = ['a', 'b', 'c']
-        >>> it(lst).zip_with_next()
+        >>> it(lst).zip_with_next().to_list()
         [('a', 'b'), ('b', 'c')]
         """
         ...
@@ -1490,12 +1490,12 @@ class Sequence(Generic[T], Iterable[T]):
         
          Example 1:
         >>> lst = ['a', 'b', 'c']
-        >>> it(lst).zip_with_next(lambda x, y: x + '__' + y)
+        >>> it(lst).zip_with_next(lambda x, y: x + '__' + y).to_list()
         ['a__b', 'b__c']
 
          Example 2:
         >>> lst = ['a', 'b', 'c']
-        >>> it(lst).zip_with_next()
+        >>> it(lst).zip_with_next().to_list()
         [('a', 'b'), ('b', 'c')]
         """
         return MergingWithNextSequence(self, transform or (lambda a, b: (a, b)))
@@ -1506,7 +1506,7 @@ class Sequence(Generic[T], Iterable[T]):
         
          Example 1:
         >>> lst = ['a', 'b', 'c']
-        >>> it(lst).with_index()
+        >>> it(lst).with_index().to_list()
         [IndexedValue(0, a), IndexedValue(1, b), IndexedValue(2, c)]
         """
         return IndexingSequence(self)
@@ -1520,18 +1520,18 @@ class Sequence(Generic[T], Iterable[T]):
 
          Example 1:
         >>> lst = ['a', 'b', 'c']
-        >>> it(lst).shuffled('123')
+        >>> it(lst).shuffled('123').to_list()
         ['b', 'a', 'c']
 
          Example 2:
         >>> from random import Random
         >>> lst = ['a', 'b', 'c']
-        >>> it(lst).shuffled(Random('123'))
+        >>> it(lst).shuffled(Random('123')).to_list()
         ['b', 'a', 'c']
 
          Example 3:
         >>> lst = ['a', 'b', 'c']
-        >>> it(lst).shuffled(123)
+        >>> it(lst).shuffled(123).to_list()
         ['c', 'b', 'a']
         """
         ...
@@ -1548,23 +1548,23 @@ class Sequence(Generic[T], Iterable[T]):
 
          Example 1:
         >>> lst = ['a', 'b', 'c']
-        >>> it(lst).shuffled('123')
+        >>> it(lst).shuffled('123').to_list()
         ['b', 'a', 'c']
 
          Example 2:
         >>> from random import Random
         >>> lst = ['a', 'b', 'c']
-        >>> it(lst).shuffled(Random('123'))
+        >>> it(lst).shuffled(Random('123')).to_list()
         ['b', 'a', 'c']
 
          Example 3:
         >>> lst = ['a', 'b', 'c']
-        >>> it(lst).shuffled(123)
+        >>> it(lst).shuffled(123).to_list()
         ['c', 'b', 'a']
         """
         return ShufflingSequence(self, random)
     
-    def partition(self, predicate: Callable[[T], bool]) -> Tuple[Sequence[T], Sequence[T]]:
+    def partition(self, predicate: Callable[[T], bool], as_sequence: bool=False) -> Tuple[Sequence[T], Sequence[T]]:
         """
          Partitions the elements of the given Sequence into two groups,
          the first group containing the elements for which the predicate returns true,
@@ -1575,7 +1575,12 @@ class Sequence(Generic[T], Iterable[T]):
         >>> it(lst).partition(lambda x: x.isalpha())
         (['a', 'b', 'c'], ['2'])
         """
-        return self.filter(predicate), self.filter(lambda x: not predicate(x))
+        part_a = self.filter(predicate)
+        part_b = self.filter(lambda x: not predicate(x))
+        if not as_sequence:
+            part_a = part_a.to_list()
+            part_b = part_b.to_list()
+        return part_a, part_b 
     
 
     @overload
@@ -1585,7 +1590,7 @@ class Sequence(Generic[T], Iterable[T]):
 
          Example 1:
         >>> lst = ['a', 'b', 'c']
-        >>> it(lst).combinations(2)
+        >>> it(lst).combinations(2).to_list()
         [('a', 'b'), ('a', 'c'), ('b', 'c')]
         """
         ...
@@ -1605,7 +1610,7 @@ class Sequence(Generic[T], Iterable[T]):
 
          Example 1:
         >>> lst = ['a', 'b', 'c']
-        >>> it(lst).combinations(2)
+        >>> it(lst).combinations(2).to_list()
         [('a', 'b'), ('a', 'c'), ('b', 'c')]
         """
         return CombinationSequence(self, n)
@@ -1629,17 +1634,17 @@ class Sequence(Generic[T], Iterable[T]):
 
          Example 1:
         >>> lst = ['a', 'b', 'c', 'd', 'e']
-        >>> it(lst).windowed(3)
+        >>> it(lst).windowed(3).to_list()
         [['a', 'b', 'c'], ['b', 'c', 'd'], ['c', 'd', 'e']]
 
          Example 2:
         >>> lst = ['a', 'b', 'c', 'd', 'e']
-        >>> it(lst).windowed(3, 2)
+        >>> it(lst).windowed(3, 2).to_list()
         [['a', 'b', 'c'], ['c', 'd', 'e']]
 
          Example 3:
         >>> lst = ['a', 'b', 'c', 'd', 'e', 'f']
-        >>> it(lst).windowed(3, 2, True)
+        >>> it(lst).windowed(3, 2, True).to_list()
         [['a', 'b', 'c'], ['c', 'd', 'e'], ['e', 'f']]
         """
         return WindowedSequence(self, size, step, partialWindows)
@@ -1651,7 +1656,7 @@ class Sequence(Generic[T], Iterable[T]):
 
          Example 1:
         >>> lst = ['a', 'b', 'c', 'd', 'e']
-        >>> it(lst).chunked(3)
+        >>> it(lst).chunked(3).to_list()
         [['a', 'b', 'c'], ['d', 'e']]
         """
         return self.windowed(size, size, True)
@@ -1664,14 +1669,14 @@ class Sequence(Generic[T], Iterable[T]):
          Example 1:
         >>> lst1 = ['a', 'b', 'c']
         >>> lst2 = [1, 2, 3]
-        >>> it(lst1).concat(lst2)
+        >>> it(lst1).concat(lst2).to_list()
         ['a', 'b', 'c', 1, 2, 3]
 
          Example 2:
         >>> lst1 = ['a', 'b', 'c']
         >>> lst2 = [1, 2, 3]
         >>> lst3 = [4, 5, 6]
-        >>> it(lst1).concat(lst2, lst3)
+        >>> it(lst1).concat(lst2, lst3).to_list()
         ['a', 'b', 'c', 1, 2, 3, 4, 5, 6]
         """
         return ConcatSequence([self, *other])
@@ -1695,7 +1700,7 @@ class Sequence(Generic[T], Iterable[T]):
          Example 1:
         >>> from tqdm import tqdm
         >>> from time import sleep
-        >>> it(range(10)).progress(lambda x: tqdm(x, total=x.len)).parallel_map(lambda x: sleep(0.), max_workers=5).to_list() and None
+        >>> it(range(10)).progress(lambda x: tqdm(x, total=len(x))).parallel_map(lambda x: sleep(0.), max_workers=5).to_list() and None
         >>> for _ in it(list(range(10))).progress(lambda x: tqdm(x, total=len(x))).to_list(): pass
         """
         return ProgressSequence(self, progress_func)
@@ -1738,7 +1743,7 @@ class Sequence(Generic[T], Iterable[T]):
          Calls the specified function [block] with `self` value as its argument and returns its result.
             
          Example 1:
-        >>> it(['a', 'b', 'c']).let(lambda x: x.map(lambda y: y + '!'))
+        >>> it(['a', 'b', 'c']).let(lambda x: x.map(lambda y: y + '!')).to_list()
         ['a!', 'b!', 'c!']
         """
         return block(self)
@@ -1748,14 +1753,13 @@ class Sequence(Generic[T], Iterable[T]):
          Calls the specified function [block] with `self` value as its argument and returns `self` value.
             
          Example 1:
-        >>> it(['a', 'b', 'c']).also(lambda x: x.map(lambda y: y + '!'))
+        >>> it(['a', 'b', 'c']).also(lambda x: x.map(lambda y: y + '!')).to_list()
         ['a', 'b', 'c']
         """
         block(self)
         return self
     
-    @property
-    def len(self) -> int:
+    def __len__(self) -> int:
         if not isinstance(self._iter, Sequence):
             if hasattr(self._iter, '__len__'):
                 return len(self._iter)
@@ -1765,12 +1769,11 @@ class Sequence(Generic[T], Iterable[T]):
             for _ in self:
                 pass
         return len(self._cache)
-    
-    def __len__(self) -> int:
-        return self.len
 
     def __repr__(self) -> str:
-        return str(self.to_list())
+        if self._cache:
+            return str(self._cache)
+        return 'Sequence(...)'
 
     def __iter__(self) -> Iterator[T]:
         if self._cache:
@@ -2106,15 +2109,15 @@ def sequence(elements: List[T]) -> Sequence[T]:
      Creates an iterator from a list of elements or given Iterable.
     
      Example 1:
-    >>> sequence('hello', 'world').map(lambda x: x.upper())
+    >>> sequence('hello', 'world').map(lambda x: x.upper()).to_list()
     ['HELLO', 'WORLD']
 
      Example 2:
-    >>> sequence(['hello', 'world']).map(lambda x: x.upper())
+    >>> sequence(['hello', 'world']).map(lambda x: x.upper()).to_list()
     ['HELLO', 'WORLD']
 
      Example 3:
-    >>> sequence(range(10)).map(lambda x: x*x)
+    >>> sequence(range(10)).map(lambda x: x*x).to_list()
     [0, 1, 4, 9, 16, 25, 36, 49, 64, 81]
     """
     ...
@@ -2129,20 +2132,16 @@ def sequence(*iterable: Iterable[T]) -> Sequence[T]:
      Creates an iterator from a list of elements or given Iterable.
     
      Example 1:
-    >>> sequence('hello', 'world').map(lambda x: x.upper())
+    >>> sequence('hello', 'world').map(lambda x: x.upper()).to_list()
     ['HELLO', 'WORLD']
 
      Example 2:
-    >>> sequence(['hello', 'world']).map(lambda x: x.upper())
+    >>> sequence(['hello', 'world']).map(lambda x: x.upper()).to_list()
     ['HELLO', 'WORLD']
 
      Example 3:
-    >>> sequence(range(10)).map(lambda x: x*x)
+    >>> sequence(range(10)).map(lambda x: x*x).to_list()
     [0, 1, 4, 9, 16, 25, 36, 49, 64, 81]
-
-     Example 4:
-    >>> sequence('abc').len
-    1
     """
     if len(iterable) == 1 and isinstance(iterable[0], Iterable) and not isinstance(iterable[0], str):
         return Sequence(iterable[0])
@@ -2154,15 +2153,15 @@ seq = sequence
     Creates an iterator from a list of elements or given Iterable.
 
     Example 1:
->>> seq('hello', 'world').map(lambda x: x.upper())
+>>> seq('hello', 'world').map(lambda x: x.upper()).to_list()
 ['HELLO', 'WORLD']
 
     Example 2:
->>> seq(['hello', 'world']).map(lambda x: x.upper())
+>>> seq(['hello', 'world']).map(lambda x: x.upper()).to_list()
 ['HELLO', 'WORLD']
 
     Example 3:
->>> seq(range(10)).map(lambda x: x*x)
+>>> seq(range(10)).map(lambda x: x*x).to_list()
 [0, 1, 4, 9, 16, 25, 36, 49, 64, 81]
 """
 
@@ -2172,15 +2171,15 @@ iterate = sequence
     Creates an iterator from a list of elements or given Iterable.
 
     Example 1:
->>> iterate('hello', 'world').map(lambda x: x.upper())
+>>> iterate('hello', 'world').map(lambda x: x.upper()).to_list()
 ['HELLO', 'WORLD']
 
     Example 2:
->>> iterate(['hello', 'world']).map(lambda x: x.upper())
+>>> iterate(['hello', 'world']).map(lambda x: x.upper()).to_list()
 ['HELLO', 'WORLD']
 
     Example 3:
->>> iterate(range(10)).map(lambda x: x*x)
+>>> iterate(range(10)).map(lambda x: x*x).to_list()
 [0, 1, 4, 9, 16, 25, 36, 49, 64, 81]
 """
 
@@ -2190,15 +2189,15 @@ it = sequence
     Creates an iterator from a list of elements or given Iterable.
 
     Example 1:
->>> it('hello', 'world').map(lambda x: x.upper())
+>>> it('hello', 'world').map(lambda x: x.upper()).to_list()
 ['HELLO', 'WORLD']
 
     Example 2:
->>> it(['hello', 'world']).map(lambda x: x.upper())
+>>> it(['hello', 'world']).map(lambda x: x.upper()).to_list()
 ['HELLO', 'WORLD']
 
     Example 3:
->>> it(range(10)).map(lambda x: x*x)
+>>> it(range(10)).map(lambda x: x*x).to_list()
 [0, 1, 4, 9, 16, 25, 36, 49, 64, 81]
 """
 
